# MoCapLib
MoCapLib: Library for Motion Capture data processing and analysis

## Description
The aim of this repository is to provide a simple Python-based library for motion capture data processing and analysis.

## Installation
MoCapLib can be installed from [PyPI](https://pypi.org/project/mocaplib/) using ```pip``` on Python>=3.7.

```bash
pip install mocaplib
```

## Usage
Currently, there is only one sub-module available, **mocaplib.gapfill**.

For the details, see [GapFill](https://github.com/mkjung99/gapfill) module.

## Dependencies
- [NumPy](https://numpy.org/)
- [SciPy](https://www.scipy.org/)

## License
[MIT](https://choosealicense.com/licenses/mit/)
